#                                               6 March 2006.  SMS.
#
#    MTOOLS 3.9.10 for VMS - MMS Dependency Description File.
#
#    MMS /EXTENDED_SYNTAX description file to generate a C source
#    dependencies file.  Unsightly errors result when /EXTENDED_SYNTAX
#    is not specified.  Typical usage:
#
#    $ MMS /EXTEND /DESCRIP = [.vms]descrip_mkdeps.mms /SKIP
#
# Note that this description file must be used from the main
# distribution directory, not from the [.VMS] subdirectory.
#
# This description file uses this command procedure:
#
#    [.VMS]COLLECT_DEPS.COM
#
# MMK users without MMS will be unable to generate the dependencies file
# using this description file, however there should be one supplied in
# the kit.  If this file has been deleted, users in this predicament
# will need to recover it from the original distribution kit.
#
# Note:  This dependency generation scheme assumes that the dependencies
# do not depend on host architecture type or other such variables. 
# Therefore, no "#include" directive in the C source itself should be
# conditional on such variables.
#

# Required command procedures.

COMS = [.VMS]COLLECT_DEPS.COM

# Include the source file lists (among other data).

INCL_DESCRIP_SRC = 1
.INCLUDE [.vms]descrip_src.mms

# The ultimate product, a comprehensive dependency list.

DEPS_FILE = [.vms]descrip_deps.mms 

# Detect valid qualifier and/or macro options.

.IF $(FINDSTRING Skip, $(MMSQUALIFIERS)) .eq Skip
DELETE_MMSD = 1
.ELSIF NOSKIP
PURGE_MMSD = 1
.ELSE
UNK_MMSD = 1
.ENDIF

# Dependency suffixes and rules.
#
# .FIRST is assumed to be used already, so the MMS qualifier/macro check
# is included in each rule (one way or another).

.SUFFIXES_BEFORE .C .MMSD

.C.MMSD :
.IF UNK_MMSD
	@ write sys$output -
 "   /SKIP_INTERMEDIATES is expected on the MMS command line."
	@ write sys$output -
 "   For normal behavior (delete .MMSD files), specify ""/SKIP""."
	@ write sys$output -
 "   To retain the .MMSD files, specify ""/MACRO = NOSKIP=1""."
	@ exit %x00000004
.ENDIF
	$(CC) $(CFLAGS_INCL) $(MMS$SOURCE) /NOLIST /NOOBJECT -
	 /MMS_DEPENDENCIES = (FILE = $(MMS$TARGET), NOSYSTEM_INCLUDE_FILES)

# List of MMS dependency files.

# In case it's not obvious...
# To extract module name lists from object library module=object lists:
# 1.  Transform "module=[.dest]name.obj" into "module=[.dest] name".
# 2.  For [.vms], add [.vms] to name.
# 3.  Delete "*]" words.
#
# A similar scheme works for executable lists.

MODS_LIB_MTOOLS_N = $(FILTER-OUT *], \
 $(PATSUBST *]*.obj, *] *, $(MODS_OBJS_LIB_MTOOLS_N)))

MODS_LIB_MTOOLS_V = $(FILTER-OUT *], \
 $(PATSUBST *]*.obj, *] [.vms]*, $(MODS_OBJS_LIB_MTOOLS_V)))

# Complete list of C object dependency file names.

DEPS = $(FOREACH NAME, \
 $(MODS_LIB_MTOOLS_N) $(MODS_LIB_MTOOLS_V), \
 $(NAME).mmsd)

# Default target is the comprehensive dependency list.

$(DEPS_FILE) : $(CONFIG_H) $(DEPS) $(COMS)
.IF UNK_MMSD
	@ write sys$output -
 "   /SKIP_INTERMEDIATES is expected on the MMS command line."
	@ write sys$output -
 "   For normal behavior (delete individual .MMSD files), specify ""/SKIP""."
	@ write sys$output -
 "   To retain the individual .MMSD files, specify ""/MACRO = NOSKIP=1""."
	@ exit %x00000004
.ENDIF
#
#       Note that the space in P3, which prevents immediate macro
#       expansion, is removed by COLLECT_DEPS.COM.
#
        @[.vms]collect_deps.com "MTOOLS" -
         "$(MMS$TARGET)" "[...]*.mmsd" "[.$ (DEST)]" $(MMSDESCRIPTION_FILE)
        @ write sys$output -
         "Created a new dependency file: $(MMS$TARGET)"
.IF DELETE_MMSD
	@ write sys$output -
         "Deleting intermediate .MMSD files..."
	delete /log *.mmsd;*, [.vms]*.mmsd;*
.ELSE
	@ write sys$output -
         "Purging intermediate .MMSD files..."
	purge /log *.mmsd, [.vms]*.mmsd
.ENDIF


# CLEAN target.

CLEAN :
	if (f$search( "$(CONFIG_H)") .nes. "") then -
	 delete /log $(CONFIG_H);*
	if (f$search( "*.mmsd;*") .nes. "") then -
	 delete /log *.mmsd;*
	if (f$search( "[.vms]*.mmsd;*") .nes. "") then -
	 delete /log [.vms]*.mmsd;*
	if (f$search( "$(DEPS_FILE);*") .nes. "") then -
	 delete /log $(DEPS_FILE);*

# PURGE target.

PURGE :
	if (f$search( "$(CONFIG_H);-1") .nes. "") then -
	 purge /log $(CONFIG_H)
	if (f$search( "*.mmsd;*") .nes. "") then -
	 delete /log *.mmsd;*
	if (f$search( "[.vms]*.mmsd;*") .nes. "") then -
	 delete /log [.vms]*.mmsd;*
	if (f$search( "$(DEPS_FILE);-1") .nes. "") then -
	 purge /log $(DEPS_FILE)


# Include CONFIG.H dependency and rule.

INCL_CONFIG_SRC = 1
.INCLUDE [.VMS]descrip_config.mms

